# filter out bogus auto-requires
%global __requires_exclude ^typelib\\((Unity)

Name:		openshot-qt
Version:	2.5.1
Release:	%mkrel 3
Summary:	Simple and Powerful video editor
Group:		Video/Editors and Converters
License:	GPLv3+
URL:		http://www.openshot.org/
Source0:	https://github.com/OpenShot/openshot-qt/archive/v%{version}/%{name}-%{version}.tar.gz
Patch0:		openshot-qt-2.5.0-fix-install.patch
BuildArch:	noarch

BuildRequires:	pkgconfig(python3)
BuildRequires:	python3dist(setuptools)
BuildRequires:	python3-qt5-devel
BuildRequires:	libopenshot-devel
BuildRequires:	libopenshot-audio-devel

Requires:	python3-qt5-core
Requires:	python3-qt5-gui
Requires:	python3-qt5-multimedia
Requires:	python3-qt5-network
Requires:	python3-qt5-opengl
Requires:	python3-qt5-printsupport
Requires:	python3-qt5-svg
Requires:	python3-qt5-webkit
Requires:	python3-qt5-webkitwidgets
Requires:	python3-qt5-widgets
Requires:	python3-libopenshot
Requires:	python3-pkg-resources
Requires:	python3dist(httplib2)
Requires:	python3dist(pillow)
Requires:	python3dist(pyxdg)
Requires:	python3dist(pyzmq)
Requires:	python3dist(setuptools)
Requires:	ffmpeg
Requires:	frei0r-plugins
Recommends:	blender
Recommends:	inkscape

Obsoletes:	openshot < 1.4.3-11
Provides:	openshot = %{version}-%{release}


%description
OpenShot Video Editor is a free, open-source, non-linear video editor. It
can create and edit videos and movies using many popular video, audio,
image formats.  Create videos for YouTube, Flickr, Vimeo, Metacafe, iPod,
Xbox, and many more common formats!

Features include:
  * Multiple tracks (layers).
  * Compositing, image overlays, and watermarks.
  * Support for image sequences (rotoscoping).
  * Key-frame animation.
  * Video and audio effects (chroma-key).
  * Transitions (lumas and masks).
  * 3D animation (titles and simulations).
  * Chroma key (green screen & blue screen).
  * Transcode (convert video encodings).
  * Upload videos (YouTube and Vimeo supported).

This is the python3 + PyQt5 version of OpenShot.

%prep
%setup -q
%autopatch -p1

%build
%py3_build

%install
%py3_install

# We strip bad shebangs (/usr/bin/env) instead of fixing them
# since these files are not executable anyways
find %{buildroot}%{python3_sitelib} -name '*.py' \
  -exec grep -q '^#!' '{}' \; -print | while read F
do
  awk '/^#!/ {if (FNR == 1) next;} {print}' $F >chopped
  touch -r $F chopped
  mv chopped $F
done

%files
%doc README.md AUTHORS
%license COPYING
%{_bindir}/%{name}
%{_datadir}/applications/org.openshot.OpenShot.desktop
%{_datadir}/mime/packages/org.openshot.OpenShot.xml
%{_datadir}/metainfo/org.openshot.OpenShot.appdata.xml
%{_iconsdir}/hicolor/*/apps/*.png
%{_iconsdir}/hicolor/scalable/apps/*.svg
%{python3_sitelib}/openshot_qt/
%{python3_sitelib}/openshot_qt-%{version}-py%{python3_version}.egg-info


%changelog
* Wed Jul 22 2020 ovitters <ovitters> 2.5.1-3.mga8
+ Revision: 1608020
- rebuild for get rid of pythonegg requires

* Mon Apr 20 2020 daviddavid <daviddavid> 2.5.1-2.mga8
+ Revision: 1569960
- switch dependencies from pythonegg(3)(xxx) to python3dist(xxx)

* Wed Mar 04 2020 daviddavid <daviddavid> 2.5.1-1.mga8
+ Revision: 1553704
- new version: 2.5.1

* Thu Feb 20 2020 umeabot <umeabot> 2.5.0-2.mga8
+ Revision: 1547651
- Mageia 8 Mass Rebuild

* Sun Feb 09 2020 daviddavid <daviddavid> 2.5.0-1.mga8
+ Revision: 1488201
- new version: 2.5.0
- rediff fix-install patch

* Sat Sep 14 2019 daviddavid <daviddavid> 2.4.4-3.mga8
+ Revision: 1440841
- rebuild for python3.8

* Thu Jun 27 2019 daviddavid <daviddavid> 2.4.4-2.mga8
+ Revision: 1400621
- add missing dependencies on python3-pkg-resources (mga#25006)

* Thu Mar 21 2019 daviddavid <daviddavid> 2.4.4-1.mga7
+ Revision: 1379470
- new version: 2.4.4

* Wed Jan 09 2019 daviddavid <daviddavid> 2.4.3-2.mga7
+ Revision: 1353808
- rebuild for new Python 3.7

* Sun Sep 23 2018 daviddavid <daviddavid> 2.4.3-1.mga7
+ Revision: 1300048
- new version: 2.4.3
- rename and rediff fix-install patch

* Thu Sep 20 2018 umeabot <umeabot> 2.4.2-3.mga7
+ Revision: 1281328
- Mageia 7 Mass Rebuild

* Sun Jul 01 2018 daviddavid <daviddavid> 2.4.2-2.mga7
+ Revision: 1241110
- filter out bogus auto-requires on typelib(Unity)

* Sun Jul 01 2018 daviddavid <daviddavid> 2.4.2-1.mga7
+ Revision: 1241085
- new version: 2.4.2
+ tv <tv>
- rebuild for new libmagic++

* Sun Dec 24 2017 daviddavid <daviddavid> 2.4.1-1.mga7
+ Revision: 1184491
- new version: 2.4.1

* Tue Sep 19 2017 daviddavid <daviddavid> 2.4.0-2.mga7
+ Revision: 1155779
- rebuild for new libopenshot 0.1.8

* Tue Sep 19 2017 daviddavid <daviddavid> 2.4.0-1.mga7
+ Revision: 1155689
- new version: 2.4.0 (mga#21729)

* Sat Aug 05 2017 pterjan <pterjan> 2.3.4-3.mga7
+ Revision: 1135284
- Rebuild for python 3.6

* Fri Jun 02 2017 akien <akien> 2.3.4-2.mga6
+ Revision: 1105838
- Obsolete old GTK+ openshot-1.4.3-10.mga6

* Fri Jun 02 2017 akien <akien> 2.3.4-1.mga6
+ Revision: 1105818
- Version 2.3.4

* Wed Dec 28 2016 daviddavid <daviddavid> 2.2.0-1.mga6
+ Revision: 1078530
- new version: 2.2.0 (fixes mga#20006)
- remove merged upstream patches

* Tue Oct 18 2016 daviddavid <daviddavid> 2.1.0-1.mga6
+ Revision: 1061550
- initial package openshot-qt

